@@ -522,7 +522,7 @@ class WePay(object):
             '/checkout/create', params=params, allowed_params=allowed_params,
             **self._update_params(params, kwargs))
 
-    def checkout_cancel(self, checkout_id, **kwargs):
+    def checkout_cancel(self, checkout_id, cancel_reason, **kwargs):
         """Call documentation: 
         `/checkout/cancel <https://www.wepay.com/developer/reference/checkout#cancel>`_, 
         plus extra keyword parameters:
@@ -532,7 +532,8 @@ class WePay(object):
         """
         allowed_params = ['checkout_id', 'cancel_reason']
         params = {
-            'checkout_id': checkout_id
+            'checkout_id': checkout_id,
+            'cancel_reason': cancel_reason
         }
         return self.make_call(
             '/checkout/cancel', params=params, allowed_params=allowed_params,
@@ -804,7 +805,7 @@ class WePay(object):
             'credit_card_id': credit_card_id
         }
         return self.make_call(
-            '/credit_card/autorize', params=params, allowed_params=allowed_params,
+            '/credit_card/authorize', params=params, allowed_params=allowed_params,
             **self._update_params(params, kwargs, keywords=['batch_mode']))
 
     def credit_card_find(self, client_id, client_secret, **kwargs):
